[glibc] linknamespace: Use 'ALLOWLIST' instead of 'WHITELIST' in code.

Carlos O'Donell carlos@sourceware.org
Wed May 21 16:49:49 GMT 2025


https://sourceware.org/git/gitweb.cgi?p=glibc.git;h=6a9df2a4032f3c4cffd0ad6557edcfbb7692acb1

commit 6a9df2a4032f3c4cffd0ad6557edcfbb7692acb1
Author: Carlos O'Donell <carlos@redhat.com>
Date:   Tue May 20 07:45:17 2025 -0400

    linknamespace: Use 'ALLOWLIST' instead of 'WHITELIST' in code.
    
    Use more inclusive language in code.
    Reviewed-by: Florian Weimer <fweimer@redhat.com>

Diff:
---
 conform/linknamespace.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/conform/linknamespace.py b/conform/linknamespace.py
index 8447f752b0..d099cac027 100644
--- a/conform/linknamespace.py
+++ b/conform/linknamespace.py
@@ -29,7 +29,7 @@ import tempfile
 
 import glibcconform
 
 # The following whitelisted symbols are also allowed for now.
 #
 # * Bug 17576: stdin, stdout, stderr only reserved with external
 # linkage when stdio.h included (and possibly not then), not
@@ -38,7 +38,7 @@ import glibcconform
 # * Bug 18442: re_syntax_options wrongly brought in by regcomp and
 # used by re_comp.
 #
-WHITELIST = {'stdin', 'stdout', 'stderr', 're_syntax_options'}
+ALLOWLIST = {'stdin', 'stdout', 'stderr', 're_syntax_options'}
 
 
 def list_syms(filename):
@@ -94,7 +94,7 @@ def main():
     with open(args.stdsyms, 'r') as stdsyms_file:
         for line in stdsyms_file:
             stdsyms.add(line.rstrip())
-    stdsyms |= WHITELIST
+    stdsyms |= ALLOWLIST
 
     # Load information about GLOBAL and WEAK symbols defined or used
     # in the standard libraries.
@@ -29,7 +29,7 @@ import tempfile
 import glibcconform
 
-# The following whitelisted symbols are also allowed for now.
+# The following ALLOWLIST symbols are also allowed for now.
 #
 # * Bug 17576: stdin, stdout, stderr only reserved with external


More information about the Glibc-cvs mailing list